rnalysis.filtering.DESeqFilter.filter\_fold\_change\_direction
==============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.filter_fold_change_direction